==> npm-groovy-lint-4.7.0.tgz: package/jdeploy-bundle/rules/UnusedImport.js <==
// Unused import

const { getVariable } = require("../utils");

const rule = {
    scope: "file",
    variables: [
        {
            name: "CLASSNAME",
            regex: /The \[(.*)\] import is never referenced/,
            regexPos: 1
        }
    ],
    unitary: true,
    fix: {
        label: "Remove unused import",
        type: "function",
        func: (allLines, variables) => {
            const lineNumber = getVariable(variables, "lineNb", { mandatory: true });
            const className = getVariable(variables, "CLASSNAME", { mandatory: true });
            if (allLines[lineNumber].includes(className)) {
                allLines.splice(lineNumber, 1);
            } else {
                const itemIndex = allLines.findIndex(line => line.includes(className));
                throw new Error(`FIX ERROR: UnusedImport aws expecting ${className} at position ${lineNumber} but it is at position ${itemIndex} `);
            }
            return allLines;
        }
    },

    tests: [
        {
            sourceBefore: `
import java.awt.notkept.Component
import java.text.notkept.SimpleDateFormat
import java.util.regex.Matcher
import javax.swing.notkept.JOptionPane
import javax.swing.notkept.filechooser.FileFilter
import javax.swing.JFileChooser
import org.apache.commons.lang3.notkept.SystemUtils

class SaMere {
    Matcher inputZ
}

class SaMere2 {
    JFileChooser inputX
}
`,
            sourceAfter: `
import java.util.regex.Matcher
import javax.swing.JFileChooser

class SaMere {
    Matcher inputZ
}
class SaMere2 {
    JFileChooser inputX
}
`
        }
    ]
};

module.exports = { rule };

==> npm-groovy-lint-4.10.0.tgz: package/jdeploy-bundle/rules/UnusedImport.js <==
// Unused import

const { getVariable } = require("../utils");

const rule = {
    scope: "file",
    variables: [
        {
            name: "CLASSNAME",
            regex: /The \[(.*)\] import is never referenced/,
            regexPos: 1
        }
    ],
    unitary: true,
    fix: {
        label: "Remove unused import",
        type: "function",
        func: (allLines, variables) => {
            const lineNumber = getVariable(variables, "lineNb", { mandatory: true });
            const className = getVariable(variables, "CLASSNAME", { mandatory: true });
            if (allLines[lineNumber].includes(className)) {
                allLines.splice(lineNumber, 1);
            } else {
                const itemIndex = allLines.findIndex(line => line.includes(className));
                throw new Error(`FIX ERROR: UnusedImport was expecting ${className} at position ${lineNumber} but it is at position ${itemIndex} `);
            }
            return allLines;
        }
    },

    tests: [
        {
            sourceBefore: `
import java.awt.notkept.Component
import java.text.notkept.SimpleDateFormat
import java.util.regex.Matcher
import javax.swing.notkept.JOptionPane
import javax.swing.notkept.filechooser.FileFilter
import javax.swing.JFileChooser
import org.apache.commons.lang3.notkept.SystemUtils

class SaMere {
    Matcher inputZ
}

class SaMere2 {
    JFileChooser inputX
}
`,
            sourceAfter: `
import java.util.regex.Matcher
import javax.swing.JFileChooser

class SaMere {
    Matcher inputZ
}
class SaMere2 {
    JFileChooser inputX
}
`
        }
    ]
};

module.exports = { rule };
